@@ -5,7 +5,7 @@ from dataclasses import dataclass
 from sys import maxsize
 from typing import Any, Dict, List, NamedTuple, NewType, Optional, Union
 
-from base58 import b58decode, b58encode
+from based58 import b58decode, b58encode
 from nacl.exceptions import BadSignatureError  # type: ignore
 from nacl.signing import VerifyKey  # type: ignore
 
@@ -30,9 +30,9 @@ class AccountMeta:
     pubkey: PublicKey
     """An account's public key."""
     is_signer: bool
-    """True if an instruction requires a transaction signature matching ``pubkey``"""
+    """True if an instruction requires a transaction signature matching `pubkey`"""
     is_writable: bool
-    """True if the ``pubkey`` can be loaded as a read-write account."""
+    """True if the `pubkey` can be loaded as a read-write account."""
 
 
 class TransactionInstruction(NamedTuple):
@@ -66,7 +66,16 @@ class SigPubkeyPair:
 
 
 class Transaction:
-    """Transaction class to represent an atomic transaction."""
+    """Transaction class to represent an atomic transaction.
+
+    Args:
+        recent_blockhash: A recent transaction id.
+        nonce_info: Nonce information.
+            If populated, transaction will use a durable Nonce hash instead of a `recent_blockhash`.
+        signatures: Signatures for the transaction.
+            Typically created by invoking the `sign()` method.
+        fee_payer: The transaction fee payer.
+    """
 
     # Default (empty) signature
     __DEFAULT_SIG = bytes(64)
@@ -96,11 +105,23 @@ class Transaction:
         )
 
     def signature(self) -> Optional[bytes]:
-        """The first (payer) Transaction signature."""
+        """The first (payer) Transaction signature.
+
+        Returns:
+            The payer signature.
+        """
         return None if not self.signatures else self.signatures[0].signature
 
     def add(self, *args: Union[Transaction, TransactionInstruction]) -> Transaction:
-        """Add one or more instructions to this Transaction."""
+        """Add one or more instructions to this Transaction.
+
+        Args:
+            *args: The instructions to add to this Transaction.
+                If a `Transaction` is passsed, the instructions will be extracted from it.
+
+        Returns:
+            The transaction with the added instructions.
+        """
         for arg in args:
             if isinstance(arg, Transaction):
                 self.instructions.extend(arg.instructions)
@@ -112,7 +133,11 @@ class Transaction:
         return self
 
     def compile_message(self) -> Message:  # pylint: disable=too-many-locals
-        """Compile transaction data."""
+        """Compile transaction data.
+
+        Returns:
+            The compiled message.
+        """
         if self.nonce_info and self.instructions[0] != self.nonce_info.nonce_instruction:
             self.recent_blockhash = self.nonce_info.nonce
             self.instructions = [self.nonce_info.nonce_instruction] + self.instructions
@@ -130,12 +155,13 @@ class Transaction:
         if not fee_payer:
             raise AttributeError("transaction feePayer required")
 
-        account_metas, program_ids = [], set()
+        account_metas, program_ids = [], []
         for instr in self.instructions:
             if not instr.program_id:
                 raise AttributeError("invalid instruction:", instr)
             account_metas.extend(instr.keys)
-            program_ids.add(str(instr.program_id))
+            if str(instr.program_id) not in program_ids:
+                program_ids.append(str(instr.program_id))
 
         # Append programID account metas.
         for pg_id in program_ids:
@@ -218,7 +244,11 @@ class Transaction:
         )
 
     def serialize_message(self) -> bytes:
-        """Get raw transaction data that need to be covered by signatures."""
+        """Get raw transaction data that need to be covered by signatures.
+
+        Returns:
+            The serialized message.
+        """
         return self.compile_message().serialize()
 
     def sign_partial(self, *partial_signers: Union[PublicKey, Keypair]) -> None:
@@ -280,7 +310,11 @@ class Transaction:
         self.add_signature(signer.public_key, signed_msg.signature)
 
     def verify_signatures(self) -> bool:
-        """Verify signatures of a complete, signed Transaction."""
+        """Verify signatures of a complete, signed Transaction.
+
+        Returns:
+            a bool indicating if the signatures are correct or not.
+        """
         return self.__verify_signatures(self.serialize_message())
 
     def __verify_signatures(self, signed_data: bytes) -> bool:
@@ -298,17 +332,22 @@ class Transaction:
 
         The Transaction must have a valid `signature` before invoking this method.
 
-        >>> from solana.keypair import Keypair
-        >>> from solana.blockhash import Blockhash
-        >>> from solana.publickey import PublicKey
-        >>> from solana.system_program import transfer, TransferParams
-        >>> seed = bytes(PublicKey(1))
-        >>> sender, receiver = Keypair.from_seed(seed), PublicKey(2)
-        >>> transfer_tx = Transaction().add(transfer(TransferParams(from_pubkey=sender.public_key, to_pubkey=receiver, lamports=1000)))
-        >>> transfer_tx.recent_blockhash = Blockhash(str(PublicKey(3)))
-        >>> transfer_tx.sign(sender)
-        >>> transfer_tx.serialize().hex()
-        '019d53be8af3a7c30f86c1092d2c3ea61d270c0cfa275a23ba504674c8fbbb724827b23b42dc8e08019e23120f1b6f40f9799355ce54185b4415be37ca2cee6e0e010001034cb5abf6ad79fbf5abbccafcc269d85cd2651ed4b885b5869f241aedf0a5ba2900000000000000000000000000000000000000000000000000000000000000020000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000301020200010c02000000e803000000000000'
+        Example:
+
+            >>> from solana.keypair import Keypair
+            >>> from solana.blockhash import Blockhash
+            >>> from solana.publickey import PublicKey
+            >>> from solana.system_program import transfer, TransferParams
+            >>> seed = bytes(PublicKey(1))
+            >>> sender, receiver = Keypair.from_seed(seed), PublicKey(2)
+            >>> transfer_tx = Transaction().add(transfer(TransferParams(from_pubkey=sender.public_key, to_pubkey=receiver, lamports=1000)))
+            >>> transfer_tx.recent_blockhash = Blockhash(str(PublicKey(3)))
+            >>> transfer_tx.sign(sender)
+            >>> transfer_tx.serialize().hex()
+            '019d53be8af3a7c30f86c1092d2c3ea61d270c0cfa275a23ba504674c8fbbb724827b23b42dc8e08019e23120f1b6f40f9799355ce54185b4415be37ca2cee6e0e010001034cb5abf6ad79fbf5abbccafcc269d85cd2651ed4b885b5869f241aedf0a5ba2900000000000000000000000000000000000000000000000000000000000000020000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000301020200010c02000000e803000000000000'
+
+        Returns:
+            The serialized transaction.
         """  # noqa: E501 pylint: disable=line-too-long
         if not self.signatures:
             raise AttributeError("transaction has not been signed")
@@ -321,7 +360,7 @@ class Transaction:
 
     def __serialize(self, signed_data: bytes) -> bytes:
         if len(self.signatures) >= SIG_LENGTH * 4:
-            raise AttributeError("too many singatures to encode")
+            raise AttributeError("too many signatures to encode")
         wire_transaction = bytearray()
         # Encode signature count
         signature_count = shortvec.encode_length(len(self.signatures))
@@ -347,20 +386,25 @@ class Transaction:
     def deserialize(raw_transaction: bytes) -> Transaction:
         """Parse a wire transaction into a Transaction object.
 
-        >>> raw_transaction = bytes.fromhex(
-        ...     '019d53be8af3a7c30f86c1092d2c3ea61d270c0cfa2'
-        ...     '75a23ba504674c8fbbb724827b23b42dc8e08019e23'
-        ...     '120f1b6f40f9799355ce54185b4415be37ca2cee6e0'
-        ...     'e010001034cb5abf6ad79fbf5abbccafcc269d85cd2'
-        ...     '651ed4b885b5869f241aedf0a5ba290000000000000'
-        ...     '0000000000000000000000000000000000000000000'
-        ...     '0000000200000000000000000000000000000000000'
-        ...     '0000000000000000000000000000000000000000000'
-        ...     '0000000000000000000000000000000000000000000'
-        ...     '000000301020200010c02000000e803000000000000'
-        ... )
-        >>> type(Transaction.deserialize(raw_transaction))
-        <class 'solana.transaction.Transaction'>
+        Example:
+
+            >>> raw_transaction = bytes.fromhex(
+            ...     '019d53be8af3a7c30f86c1092d2c3ea61d270c0cfa2'
+            ...     '75a23ba504674c8fbbb724827b23b42dc8e08019e23'
+            ...     '120f1b6f40f9799355ce54185b4415be37ca2cee6e0'
+            ...     'e010001034cb5abf6ad79fbf5abbccafcc269d85cd2'
+            ...     '651ed4b885b5869f241aedf0a5ba290000000000000'
+            ...     '0000000000000000000000000000000000000000000'
+            ...     '0000000200000000000000000000000000000000000'
+            ...     '0000000000000000000000000000000000000000000'
+            ...     '0000000000000000000000000000000000000000000'
+            ...     '000000301020200010c02000000e803000000000000'
+            ... )
+            >>> type(Transaction.deserialize(raw_transaction))
+            <class 'solana.transaction.Transaction'>
+
+        Returns:
+            The deserialized transaction.
         """
         signatures = []
         signature_count, offset = shortvec.decode_length(raw_transaction)
@@ -373,22 +417,27 @@ class Transaction:
     def populate(message: Message, signatures: List[bytes]) -> Transaction:
         """Populate Transaction object from message and signatures.
 
-        >>> raw_message = bytes.fromhex(
-        ...     '0200030500000000000000000000000000000000000000000000'
-        ...     '0000000000000000000100000000000000000000000000000000'
-        ...     '0000000000000000000000000000000200000000000000000000'
-        ...     '0000000000000000000000000000000000000000000300000000'
-        ...     '0000000000000000000000000000000000000000000000000000'
-        ...     '0004000000000000000000000000000000000000000000000000'
-        ...     '0000000000000005c49ae77603782054f17a9decea43b444eba0'
-        ...     'edb12c6f1d31c6e0e4a84bf052eb010403010203050909090909'
-        ... )
-        >>> from base58 import b58encode
-        >>> from solana.message import Message
-        >>> msg = Message.deserialize(raw_message)
-        >>> signatures = [b58encode(bytes([1] * SIG_LENGTH)), b58encode(bytes([2] * SIG_LENGTH))]
-        >>> type(Transaction.populate(msg, signatures))
-        <class 'solana.transaction.Transaction'>
+        Example:
+
+            >>> raw_message = bytes.fromhex(
+            ...     '0200030500000000000000000000000000000000000000000000'
+            ...     '0000000000000000000100000000000000000000000000000000'
+            ...     '0000000000000000000000000000000200000000000000000000'
+            ...     '0000000000000000000000000000000000000000000300000000'
+            ...     '0000000000000000000000000000000000000000000000000000'
+            ...     '0004000000000000000000000000000000000000000000000000'
+            ...     '0000000000000005c49ae77603782054f17a9decea43b444eba0'
+            ...     'edb12c6f1d31c6e0e4a84bf052eb010403010203050909090909'
+            ... )
+            >>> from based58 import b58encode
+            >>> from solana.message import Message
+            >>> msg = Message.deserialize(raw_message)
+            >>> signatures = [b58encode(bytes([1] * SIG_LENGTH)), b58encode(bytes([2] * SIG_LENGTH))]
+            >>> type(Transaction.populate(msg, signatures))
+            <class 'solana.transaction.Transaction'>
+
+        Returns:
+            The populated transaction.
         """
         transaction = Transaction(recent_blockhash=message.recent_blockhash)
 
