@@ -2,7 +2,7 @@
 
 from base64 import b64decode
 
-from base58 import b58decode
+from based58 import b58decode
 
 
 def from_uint8_bytes(uint8: bytes) -> int:
@@ -16,7 +16,7 @@ def to_uint8_bytes(val: int) -> bytes:
 
 
 def decode_byte_string(byte_string: str, encoding: str = "base64") -> bytes:
-    """Decode a encoded string from an RPC Response."""
+    """Decode an encoded string from an RPC Response."""
     b_str = str.encode(byte_string)
     if encoding == "base64":
         return b64decode(b_str)
